@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 1998-2016 Sergey Poznyakoff
+   Copyright (C) 1998-2020 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include <dico/types.h>
 
 extern const char *dico_markup_type;
-dico_list_t dico_markup_list;
+extern dico_list_t dico_markup_list;
 const char *dico_markup_lookup(const char *name);
 int dico_markup_register(const char *name);
 
